@@ -2,6 +2,9 @@ import matplotlib as _mpl
 import numpy as _np
 from atlas_mpl_style.utils import significance as _significance
 
+# For histograms with no color set
+_hist_colors = _mpl.rcParams["axes.prop_cycle"]()
+
 
 class BinningMismatchError(Exception):
     "Error due to histogram binning mismatch"
@@ -41,10 +44,13 @@ class Background:
 
         self.hist = hist
         self.stat_errs = stat_errs
-        self.color = color
+        if color is None:
+            self.color = next(_hist_colors)["color"]
+        else:
+            self.color = color
         self.label = label
         if syst_errs is None:
-            syst_errs = _np.zeros_like(stat_errs)
+            self.syst_errs = _np.zeros_like(stat_errs)
         else:
             self.syst_errs = syst_errs
 
@@ -133,15 +139,16 @@ def plot_backgrounds(bins, backgrounds, ax=None):
     )
     for p in ps:
         _mpl.pyplot.setp(p, edgecolor="k", lw=1)
-    plot_band(
-        bins,
-        total_hist - total_err,
-        total_hist + total_err,
-        color="grey",
-        alpha=0.5,
-        label="Stat. $\\bigoplus$ Syst. Unc.",
-        zorder=5,
-    )
+    if _np.sum(total_syst_err) != 0.0:
+        plot_band(
+            bins,
+            total_hist - total_err,
+            total_hist + total_err,
+            color="grey",
+            alpha=0.5,
+            label="Stat. $\\bigoplus$ Syst. Unc.",
+            zorder=5,
+        )
     plot_band(
         bins,
         total_hist - total_stat_err,
@@ -396,19 +403,25 @@ def plot_1d(label, bins, hist, stat_errs=None, color=None, ax=None, **kwargs):
         ax = _mpl.pyplot.gca()
     if len(bins) - 1 != len(hist):
         raise BinningMismatchError("Invalid binning")
-    if stat_errs is None:
-        stat_errs = _np.sqrt(hist)
-    if len(bins) - 1 != len(stat_errs):
-        raise BinningMismatchError("Incorrect binning for stat errors")
+    if stat_errs is not None:
+        if len(bins) - 1 != len(stat_errs):
+            raise BinningMismatchError("Incorrect binning for stat errors")
     bin_centers = (bins[1:] + bins[:-1]) / 2
     _, _, p = ax.hist(
-        bin_centers, bins=bins, weights=hist, histtype="step", color=color, label=label,
+        bin_centers,
+        bins=bins,
+        weights=hist,
+        histtype="step",
+        color=color,
+        label=label,
+        **kwargs,
     )
     if color is None:
         color = p[0].get_ec()
-    plot_band(
-        bins, hist - stat_errs, hist + stat_errs, color=color, alpha=0.3, zorder=5
-    )
+    if stat_errs is not None:
+        plot_band(
+            bins, hist - stat_errs, hist + stat_errs, color=color, alpha=0.3, zorder=5
+        )
 
 
 def plot_2d(xbins, ybins, hist, ax=None, pad=0.005, **kwargs):
